@@ -10,7 +10,6 @@
 
 #include <QDateTime>
 #include <QFileInfo>
-#include <QImage>
 #include <QMutexLocker>
 #include <QPainter>
 #include <QPixmap>
@@ -202,12 +201,11 @@ QPixmap KCardCachePrivate::renderSvg(const QString &element)
     return doRender(element, renderer(), size);
 }
 
-void KCardCachePrivate::submitRendering(const QString &key, const QImage &image)
+void KCardCachePrivate::submitRendering(const QString &key, const QPixmap &pixmap)
 {
     qCDebug(LSKAT_LOG) << "Received render of" << key << "from rendering thread.";
-    QPixmap pix = QPixmap::fromImage(image);
     QMutexLocker l(cacheMutex);
-    cache->insertPixmap(key, pix);
+    cache->insertPixmap(key, pixmap);
 }
 
 LoadThread::LoadThread(KCardCachePrivate *d_)
@@ -256,7 +254,7 @@ void LoadThread::run()
             if (doKill)
                 return;
         }
-        QImage img = QImage(size, QImage::Format_ARGB32);
+        QPixmap img(size);
         img.fill(Qt::transparent);
         QPainter p(&img);
         {
@@ -416,63 +414,6 @@ void KCardCache::loadTheme(LoadInfos infos)
     d->loadThread->start(QThread::IdlePriority);
 }
 
-QSizeF KCardCache::defaultCardSize(KCardInfo info) const
-{
-    if (d->deckName.isEmpty())
-        return QSizeF();
-
-    QPixmap pix;
-    QString key = d->deckName + QLatin1Char('_') + info.svgName() + QLatin1String("_default");
-    {
-        QMutexLocker(d->cacheMutex);
-        if (d->cache && d->cache->findPixmap(key, &pix))
-            return pix.size();
-    }
-
-    {
-        QMutexLocker(d->rendererMutex);
-        QSizeF size = d->renderer()->boundsOnElement(info.svgName()).size();
-        pix = QPixmap(size.toSize());
-    }
-
-    {
-        QMutexLocker(d->cacheMutex);
-        if (d->cache)
-            d->cache->insertPixmap(key, pix);
-    }
-
-    return pix.size();
-}
-
-QSizeF KCardCache::defaultBackSize() const
-{
-    if (d->deckName.isEmpty())
-        return QSizeF();
-
-    QString element = QStringLiteral("back");
-    QPixmap pix;
-    QString key = d->deckName + QLatin1Char('_') + element + QLatin1String("_default");
-    {
-        QMutexLocker(d->cacheMutex);
-        if (d->cache && d->cache->findPixmap(key, &pix))
-            return pix.size();
-    }
-
-    {
-        QMutexLocker(d->rendererMutex);
-        QSizeF size = d->renderer()->boundsOnElement(element).size();
-        pix = QPixmap(size.toSize());
-    }
-
-    {
-        QMutexLocker(d->cacheMutex);
-        if (d->cache)
-            d->cache->insertPixmap(key, pix);
-    }
-
-    return pix.size();
-}
-
 void KCardCache::invalidateCache()
 {
     QMutexLocker l(d->cacheMutex);
