@@ -1,20 +1,8 @@
 /*
     This file is part of the KDE games library
-    Copyright 2008 Andreas Pakulat <apaku@gmx.de>
+    SPDX-FileCopyrightText: 2008 Andreas Pakulat <apaku@gmx.de>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KCARDDIALOG_H
@@ -100,7 +88,7 @@ public:
     /**
      * Destructs a card deck selection dialog.
      */
-    ~KCardWidget();
+    ~KCardWidget() override;
 
     /**
      * Saves the KCardWidget config into a config file.
